@ECHO OFF

:: This script puts the platform-appropriate Helix component executables in the
:: 'perforce' subdirectory.
::
:: If run with no arguments, it pulls packaged executables from the
:: perforce\Win32 or perforce\Win64 subdirectory, and simply copies them up to
:: the perforce directory.
::
:: If run with the 'latest' option, as in 'GetHelixComponents.bat latest',
:: it downloads the latest patches from the Perforce FTP server.  This usage requires
:: an active internet connection, and may take a while to run depending on
:: network performance.  If attempts to download fail, the script reverts back to
:: copying the packaged executables.
::
:: Perforce versions for each Helix component are identified below.  Be careful to update
:: version (e.g. "16.1") in both Win32 and Win64 blocks of the IF/ELSE statement
:: below if they need to change.  Note that P4V releases on a different schedule, and
:: so not always lock-step in sync with other executables.  For example, P4V might be
:: at 15.2 when P4D is at 16.1.
::
:: Coding note: Don't be tempted to change the 'IF NOT EXIST tmp.download\blah.exe' check
:: to an 'IF NOT ERRORLEVEL 0' test.  While curle.exe returns a return status reliably,
:: the test for ERRORLEVEL doesn't work in a () code block (due to a bug in Windows
:: batch files).  Batch executes only see the first test.  But if each test is different,
:: each is executed. (This might be fixed on newer versions of Windows; the code will work
:: as is on Windows 7 at least).

FOR %%F IN (p4.exe p4d.exe p4p.exe p4broker.exe helix-versioning-engine-x86.exe p4vinst.exe helix-versioning-engine-x64.exe p4vinst64.exe) DO (
   DEL /F /Q perforce\%%F > NUL 2>&1
)

IF NOT %1x==latestx ( GOTO CopyPlatformExes )


IF EXIST "%ProgramFiles(x86)%" (
   IF NOT EXIST perforce\Win64 ( MKDIR perforce\Win64 )
   RD /S /Q tmp.download > NUL 2>&1
   MKDIR tmp.download\Win64
   ECHO Downloading 64 bit executables and installers.
   ECHO Downloading p4.exe 2016.1
   .\curl.exe -s -o tmp.download\Win64\p4.exe ftp://ftp.perforce.com/perforce/r16.1/bin.ntx64/p4.exe
   IF NOT EXIST tmp.download\Win64\p4.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO Downloading p4d.exe 2016.1
   .\curl.exe -s -o tmp.download\Win64\p4d.exe ftp://ftp.perforce.com/perforce/r16.1/bin.ntx64/p4d.exe
   IF NOT EXIST tmp.download\Win64\p4d.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO Downloading p4p.exe 2016.1
   .\curl.exe -s -o tmp.download\Win64\p4p.exe ftp://ftp.perforce.com/perforce/r16.1/bin.ntx64/p4p.exe
   IF NOT EXIST tmp.download\Win64\p4p.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO Downloading p4broker.exe 2016.1
   .\curl.exe -s -o tmp.download\Win64\p4broker.exe ftp://ftp.perforce.com/perforce/r16.1/bin.ntx64/p4broker.exe
   IF NOT EXIST tmp.download\Win64\p4broker.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO Downloading helix-versioning-engine-x64.exe 2016.1
   .\curl.exe -s -o tmp.download\Win64\helix-versioning-engine-x64.exe ftp://ftp.perforce.com/perforce/r16.1/bin.ntx64/helix-versioning-engine-x64.exe
   IF NOT EXIST tmp.download\Win64\helix-versioning-engine-x64.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO Downloading p4vinst.exe 2015.2
   .\curl.exe -s -o tmp.download\Win64\p4vinst64.exe ftp://ftp.perforce.com/perforce/r15.2/bin.ntx64/p4vinst64.exe
   IF NOT EXIST tmp.download\Win64\p4vinst64.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )

   ECHO All files downloaded OK.  Moving downloaded files to %CD%\perforce.
   MOVE /Y tmp.download\Win64\*.exe perforce\Win64
   GOTO Done
) ELSE (
   IF NOT EXIST perforce\Win32 ( MKDIR perforce\Win32 )
   RD /S /Q tmp.download > NUL 2>&1
   MKDIR tmp.download\Win32
   ECHO Downloading 32 bit executables and installers.
   ECHO Downloading p4.exe 2016.1
   .\curl.exe -s -o tmp.download\Win32\p4.exe ftp://ftp.perforce.com/perforce/r16.1/bin.ntx86/p4.exe
   IF NOT EXIST tmp.download\Win32\p4.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO Downloading p4d.exe 2016.1
   .\curl.exe -s -o tmp.download\Win32\p4d.exe ftp://ftp.perforce.com/perforce/r16.1/bin.ntx86/p4d.exe
   IF NOT EXIST tmp.download\Win32\p4d.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO Downloading p4p.exe 2016.1
   .\curl.exe -s -o tmp.download\Win32\p4p.exe ftp://ftp.perforce.com/perforce/r16.1/bin.ntx86/p4p.exe
   IF NOT EXIST tmp.download\Win32\p4p.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO Downloading p4broker.exe 2016.1
   .\curl.exe -s -o tmp.download\Win32\p4broker.exe ftp://ftp.perforce.com/perforce/r16.1/bin.ntx86/p4broker.exe
   IF NOT EXIST tmp.download\Win32\p4broker.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO Downloading helix-versioning-engine-x86.exe 2016.1
   .\curl.exe -s -o tmp.download\Win32\helix-versioning-engine-x86.exe ftp://ftp.perforce.com/perforce/r16.1/bin.ntx86/helix-versioning-engine-x86.exe
   IF NOT EXIST tmp.download\Win32\helix-versioning-engine-x86.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO Downloading p4vinst.exe 2015.2
   .\curl.exe -s -o tmp.download\Win32\p4vinst.exe ftp://ftp.perforce.com/perforce/r15.2/bin.ntx86/p4vinst.exe
   IF NOT EXIST tmp.download\Win32\p4vinst.exe (
      ECHO Problem downloading. Copying packaged executables instead.
      GOTO CopyPlatformExes
   )
   ECHO All files downloaded OK.  Moving downloaded files to %CD%\perforce.
   MOVE /Y tmp.download\Win32\*.exe perforce\Win32
   GOTO Done
)

:CopyPlatformExes

IF EXIST "%ProgramFiles(x86)%" (
   COPY /Y perforce\Win64\*.exe perforce\.
) ELSE (
   COPY /Y perforce\Win32\*.exe perforce\.
)

:Done
ECHO .
ECHO Done: Helix executables are available in: %CD%\perforce
