@setlocal
@echo off

:: This script runs the installers - expects stuff to have been setup by install.bat

rem INFORMATION FOR EDITING
rem
rem This batch file is organized in 5 basic sections
rem 
rem 1. Installer Parameter Variables
rem     Here is where you list all the parameters that will be passed to the installers.
rem     New variables added here must be added to the Installer Parameters list.
rem     Currently only 2 services are supported but more may be added by updating
rem     the installer executable code.
rem 
rem 2. Batch Command Variables
rem     Here are all the variables that are used by the batch commands in this file.
rem     Adding new variables here will not add new functionality. New functionality can
rem     only be added by adding batch commands to the Installation/Uninstallation Steps.
rem     Those new commands should then use the new variables created here.
rem
rem 3. Installer Parameters
rem     Here is where you create the list of parameters to be passed to the installers.
rem     New Installer Parameter Variables must be added here in order to be used.
rem     When adding new installers to Installation/Uninstallation Steps you should
rem     create a new _params variable and set it to at least %log_params%, then pass
rem     that _params variable to the new installer. Please see existing examples for
rem     assistance
rem 
rem 4. Installation Steps
rem     Here is where the actual installation takes place.
rem     If you wish to add new functionality please use the existing commands as a guide.
rem     Additionally, you should create error checks with appropriate messages after most
rem     operations. If you add new installers and they are not part of the standard training
rem     class then please add an 'if exist perforce\<new_installer>' statement before you
rem     call the installer so that it will not be installed as part of the standard training class.
rem     Make sure that the creation of the marker file is the last command in this section.
rem 
rem 5. Uninstallation Steps
rem      Here is where the actual uninstallation takes place.
rem      Changes to the Installation Steps should be considered here and appropriate action
rem      should be taken to cleanup after ourselves. See Installation Steps above for notes
rem      on adding new installers not part of the standard training class.
rem      Make sure that the deletion of our folders and the marker file are the last commands
rem      in this section.

SET INSTALL_PATH=
if %1x==x (
    echo ERROR: Required parameter INSTALL_PATH value not defined.
    echo .
    exit /b 1
)
set INSTALL_PATH=%1

rem Installer Parameter Variables 
set server_1_root=%install_path%
set server_1_port=1666
set p4port=localhost:1666
set p4journal=%server_1_root%\journal
set p4user=bruno
set p4client=bruno_ws
set p4editor=notepad

rem Batch Command Variables
set server_1_depot=depot
set server_1_depot2=Sim
set server_1_checkpoint=checkpoint 
set p4v_installer=p4vinst.exe
if exist p4vinst64.exe set p4v_installer=p4vinst64.exe
set bruno_root_1=c:\bruno_ws
set installed_marker="%ALLUSERSPROFILE%\trninstd"

rem Installer Parameters 
set log_params=/v"/qr /l+* %TEMP%\PerforceMSI.log
set p4v_params=%log_params%
set p4v_params=%p4v_params% P4PORT=%p4port%
set p4v_params=%p4v_params% INSTDIR=%install_path%
set p4v_params=%p4v_params% P4USER=%p4user%
set p4v_params=%p4v_params% P4EDITOR=%p4editor%
set p4v_params=%p4v_params% P4CLIENT=%p4client%
set p4v_params=%p4v_params% REBOOT=ReallySuppress
set p4v_params=%p4v_params% ADDLOCAL=ALL 

rem If called from uninstall.bat then force uninstall
if (%2)==(uninstall) goto uninstall

rem If file used to mark training installer as installed exists then uninstall
:: if exist %installed_marker% goto uninstall

cd /d %server_1_root%

:: Assume unzip program is there
set UNZIP=%p4root%\7za.exe

:: Unzip depot files etc, also checkpoint(s)
@echo ============================================================================================
@echo If installing onto a machine which already has this directory - answer (A)llways if prompted.
@echo ============================================================================================
%UNZIP% x PerforceTraining.zip

rem Installation Steps
:install
title Perforce Training Installer
echo.
echo Installing...

@echo Replay checkpoint(s)
%server_1_root%\p4d.exe -r %server_1_root% -jr %server_1_root%\%server_1_checkpoint%> nul 2>&1 
if not (%errorlevel%)==(0) set errstr=ERROR REPLAYING SERVER 1 CHECKPOINT. && goto error

@echo Upgrade server database...
%server_1_root%\p4d.exe -r %server_1_root% -xu
if not (%errorlevel%)==(0) set errstr=ERROR UPGRADING SERVER 1 DATABASE. && goto error

rem Install P4V
if exist %p4v_installer% %p4v_installer%  %p4v_params%"
if not (%errorlevel%)==(0) set errstr=ERROR INSTALLING P4V. && goto error

rem Create file to mark training installer as installed
echo Perforce training installation file. Do not delete.>%installed_marker%

goto finished

rem Uninstallation Steps
:uninstall
title Perforce Training Uninstaller
echo.
echo Uninstalling...

rem Delete all the folders we created
rmdir /s /q %install_path%> nul 2>&1
rmdir /s /q %server_1_root%> nul 2>&1
rmdir /s /q %bruno_root_1%> nul 2>&1

rem If any uninstall errors then display them and exit
if not ("%errstr%")==("") goto error

rem Delete file used to mark the training installer as installed
del %installed_marker%> nul 2>&1

rem Uninstall P4V
@echo If you do not wish to uninstall P4V, hit Ctrl-C and answer Y to the terminate prompt.
@pause
if exist %p4v_installer% %p4v_installer% %log_params% REMOVE=ALL"
if not (%errorlevel%)==(0) set errstr=%errstr% ERROR UNINSTALLING P4V.

goto end


:error
echo.
echo %errstr%
echo.
pause
goto end


:finished
echo.
@echo Run the following commands if you want your environment to default to the training install.
@echo p4 set P4USER=bruno
@echo p4 set P4PORT=1666
@echo p4 set P4CLIENT=bruno_ws
echo.
@echo Save your current settings first though by running:
@echo p4 set ^> settings.txt
echo.
echo Finished!
@echo Please start the Perforce server by running:
@echo cd %install_path%
@echo server.bat

:: exit

:end

@endlocal
