@echo off

:: USAGE: install.bat [latest|uninstall]
::
::    Install using pre-packged executables:
::    CD /D X:\where\you\extracted\training-onsite.zip
::    .\install.bat
::
::    That will install with packaged executables.  To attempt to download the
::    latest patches of the executables from the FTP site, add the 'latest' argument:
::    .\install.bat latest
::
::    If 'latest' is specified and downloading fails, the pagkaged executables will
::    be used instead.
::
::    To uninstall, add the 'uninstall' argument:
::    .\install.bat uninstall

:: INFORMATION FOR EDITING
rem
:: This batch file is organized in 5 basic sections
:: 
:: 1. Installer Parameter Variables
::     Here is where you list all the parameters that will be passed to the installers.
::     New variables added here must be added to the Installer Parameters list.
::     Currently only 2 services are supported but more may be added by updating
::     the installer executable code.
:: 
:: 2. Batch Command Variables
::     Here are all the variables that are used by the batch commands in this file.
::     Adding new variables here will not add new functionality. New functionality can
::     only be added by adding batch commands to the Installation/Uninstallation Steps.
::     Those new commands should then use the new variables created here.
rem
:: 3. Installer Parameters
::     Here is where you create the list of parameters to be passed to the installers.
::     New Installer Parameter Variables must be added here in order to be used.
::     When adding new installers to Installation/Uninstallation Steps you should
::     create a new _params variable and set it to at least %log_params%, then pass
::     that _params variable to the new installer. Please see existing examples for
::     assistance
:: 
:: 4. Installation Steps
::     Here is where the actual installation takes place.
::     If you wish to add new functionality please use the existing commands as a guide.
::     Additionally, you should create error checks with appropriate messages after most
::     operations. If you add new installers and they are not part of the standard training
::     class then please add an 'if exist perforce\<new_installer>' statement before you
::     call the installer so that it will not be installed as part of the standard training class.
::     Make sure that the creation of the marker file is the last command in this section.
:: 
:: 5. Uninstallation Steps
::      Here is where the actual uninstallation takes place.
::      Changes to the Installation Steps should be considered here and appropriate action
::      should be taken to cleanup after ourselves. See Installation Steps above for notes
::      on adding new installers not part of the standard training class.
::      Make sure that the deletion of our folders and the marker file are the last commands
::      in this section.

:: Installer Parameter Variables 
set install_path=C:\P4Training
set server_1_root=%install_path%
set server_1_port=1666
set p4port=localhost:1666
set p4user=bruno
set p4client=bruno_ws
set p4editor=notepad
set get_exe_option=Unset
set uninstall_option=Unset
set arg_ok=Unset

:: Comand Line Parsing

if (%1)==() goto DoneParsingCommandLine

if (%1)==(latest) (
   set get_exe_option=latest
   set arg_ok=OK
)

if (%1)==(uninstall) (
   set uninstall_option=TRUE
   set arg_ok=OK
)

if (%arg_ok%)==(Unset) (
   echo .
   echo Usage Error: Invalid argument [%1].
   echo .
   echo Run install.bat with no arguments to install with packaged exes:
   echo .
   echo .\install.bat
   echo .
   echo Or, to try and download the latest exes from the Perforce FTP site:
   echo .
   echo .\install.bat latest
   echo .
   echo Or, to uninstall:
   echo .\install.bat uninstall
   echo .
   exit /b 1
)

:DoneParsingCommandLine

if (%get_exe_option%)==(latest) (
   echo Acquiring latest Helix components.
) else (
   echo Using packaged Helix components.
)

if (%uninstall_option%)==(TRUE) ( echo Uninstall selected. )

:: Batch Command Variables
set server_1_checkpoint=checkpoint

:: Select 64 or 32 bit installer, depending on which machine
:: we're on.
if exist "%ProgramFiles(x86)%" (
   set server_installer=helix-versioning-engine-x64.exe
   set p4v_installer=p4vinst64.exe
) else (
   set server_installer=helix-versioning-engine-x86.exe
   set p4v_installer=p4vinst.exe
)
set bruno_root_1=C:\bruno_ws
set installed_marker="%ALLUSERSPROFILE%\trninstd"

:: Installer Parameters 
set log_params=/v"/qr /l+* %TEMP%\PerforceMSI.log
set server_params=%log_params%
set server_params=%server_params% P4PORT=%p4port%
set server_params=%server_params% SERVROOT=%server_1_root%
set server_params=%server_params% SERVPORT=%server_1_port%
set server_params=%server_params% INSTDIR=%install_path%
set server_params=%server_params% P4USER=%p4user%
set server_params=%server_params% P4EDITOR=%p4editor%
set server_params=%server_params% P4CLIENT=%p4client%
set server_params=%server_params% REBOOT=ReallySuppress
set p4v_params=%log_params%
set p4v_params=%p4v_params% P4PORT=%p4port%
set p4v_params=%p4v_params% INSTDIR=%install_path%
set p4v_params=%p4v_params% P4USER=%p4user%
set p4v_params=%p4v_params% P4EDITOR=%p4editor%
set p4v_params=%p4v_params% P4CLIENT=%p4client%
set p4v_params=%p4v_params% REBOOT=ReallySuppress
set p4v_params=%p4v_params% ADDLOCAL=ALL REMOVE=P4
set errstr=

:: Display error if running from a UNC path
set filepath=%0
set drive=%filepath:~1,2%
if (%drive%)==(\\) set errstr=PLEASE MAP UNC PATH AS NETWORK DRIVE AND INSTALL FROM THAT DRIVE. && goto error

:: Display error if running from another directory
if not exist install.bat set errstr=PLEASE CHANGE TO THIS BATCH FILE'S DIRECTORY BEFORE RUNNING. && goto error

title Perforce Training Installer
echo.
echo Acquiring Helix component executables ...
if (%get_exe_option%)==(Unset) (
   CALL GetHelixComponents.bat
) else (
   CALL GetHelixComponents.bat %get_exe_option%
)

:: If called from uninstall.bat then force uninstall
:: if (%uninstall_option%)==(TRUE) ( goto uninstall )

:: If file used to mark training installer as installed exists then uninstall
:: if exist %installed_marker% (
::    echo Previous install marker file detected: %installed_marker%
::    goto uninstall
:: )

:: Installation Steps
:install
echo.
echo Installing ...

:: Delete any of our folders that may have been left behind from a previous installation
echo Preparing to install.
rmdir /s /q %install_path%> nul 2>&1
rmdir /s /q %server_1_root%> nul 2>&1
rmdir /s /q %server_1_root%> nul 2>&1
rmdir /s /q %bruno_root_1%> nul 2>&1
rmdir /s /q %bruno_root_1%> nul 2>&1
mkdir %server_1_root%

:: Install server
:: perforce\%server_installer% %server_params%"
:: if not ERRORLEVEL 0 (
::    if not ERRORLEVEL 3010 (
::       set errstr=ERROR INSTALLING SERVER.
::       goto error
::    )
:: )

echo Copying executable files to server root.
xcopy perforce\*.exe %server_1_root% /E /Q /R /K /Y
if not ERRORLEVEL 0 (
   set errstr=ERROR COPYING SERVER 1 EXECUTABLES.
   goto error
)

echo Copying depots to server root.
xcopy depots %server_1_root%\depots /E /I /Q /R /K /Y> nul 2>&1 
if not ERRORLEVEL 0 (
   set errstr=ERROR COPYING SERVER 1 DEPOTS.
   goto error
)

echo Removing the read-only attribute from the checkpoint file
xcopy checkpoint %server_1_root% /E /I /Q /R /K /Y> nul 2>&1 
attrib -r %server_1_root%\checkpoint /s

echo Replaying checkpoint
del /f /q %install_path%\db.* > nul 2>&1
echo "%server_1_root%\p4d.exe -r %server_1_root% -jr %server_1_root%\%server_1_checkpoint%"
%server_1_root%\p4d.exe -r %server_1_root% -jrF %server_1_root%\%server_1_checkpoint%

if not ERRORLEVEL 0 (
   set errstr=ERROR REPLAYING SERVER 1 CHECKPOINT.
   goto error
)

:: Make Needed Dirs
IF NOT EXIST C:\P4Training\logs (MKDIR C:\P4Training\logs)
IF NOT EXIST C:\P4Training\checkpoints (MKDIR C:\P4Training\checkpoints)

echo Upgrading Databases
echo "%server_1_root%\p4d.exe -r %server_1_root% -xu"
%server_1_root%\p4d.exe -r %server_1_root% -xu

if not ERRORLEVEL 0 (
   set errstr=ERROR UPGRADING DATABASES.
   goto error
)

:: Delete any P4CONFIG settings from registry
:: reg delete HKCU\Environment /v P4CONFIG /f> nul 2>&1
:: reg delete HKCU\Software\Perforce /v P4CONFIG /f> nul 2>&1
:: reg delete HKLM\SOFTWARE\Perforce /v P4CONFIG /f> nul 2>&1
:: reg delete HKLM\SOFTWARE\Wow6432Node\Perforce /v P4CONFIG /f> nul 2>&1
:: reg delete "HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment" /v P4CONFIG /f> nul 2>&1
:: reg delete HKLM\SYSTEM\CurrentControlSet\Services\Perforce\Parameters /v P4CONFIG /f> nul 2>&1
:: reg delete HKLM\SYSTEM\CurrentControlSet\Services\Perforce2\Parameters /v P4CONFIG /f> nul 2>&1

:: Install P4V
:: perforce\%p4v_installer% %p4v_params%"
echo Install P4V from https://www.perforce.com/downloads/helix-visual-client-p4v
:: if not ERRORLEVEL 0 (
::    if not ERRORLEVEL 3010 (
::       set errstr=ERROR INSTALLING P4V.
::       goto error
::    )
:: )

:: Create file to mark training installer as installed
:: Do this before installing P4V since it requires reboot which would circumvent
:: the rest of the script
echo Perforce training installation file. Do not delete.>%installed_marker%

p4 set P4USER=bruno
p4 set P4PORT=1666
p4 set P4CLIENT=bruno_ws

goto finished

:: Uninstallation Steps
:uninstall
:: title Perforce Training Uninstaller
:: echo.
:: echo Uninstalling ...

:: Uninstall P4V
echo Checking to see if P4V is installed.
:: wmic product list brief | findstr /c:"Perforce Visual Components" > NUL 2>&1
:: REG QUERY HKLM\Software\Microsoft\Windows\CurrentVersion\Installer\UpgradeCodes\7CDF9A07B588D6D4ABDFBCD272BA9236 > NUL 2>&1

if ERRORLEVEL 1 (
   echo P4V is not installed.
) else (
   echo P4V is installed.
   :: echo P4V is installed.  Uninstalling P4V.
   :: perforce\%p4v_installer% %log_params% REBOOT=ReallySuppress REMOVE=ALL"
   :: if NOT ERRORLEVEL 0 if NOT ERRORLEVEL 3010 set errstr=%errstr% ERROR UNINSTALLING P4V.
)

:: Uninstall server
echo Checking to see if P4D is installed.
:: wmic product list brief | findstr /c:"Helix Versioning Engine" > NUL 2>&1
:: REG QUERY HKLM\Software\Microsoft\Windows\CurrentVersion\Installer\UpgradeCodes\846BADE91D81CE1488F8E03CBD9236E2 > NUL 2>&1

if ERRORLEVEL 1 (
   echo P4D is not installed.
) else (
   echo P4D is installed.
   :: echo P4D is installed.  Uninstalling P4D.
   :: perforce\%server_installer% %log_params% REBOOT=ReallySuppress REMOVE=ALL"
   :: if NOT ERRORLEVEL 0 if NOT ERRORLEVEL 3010 set errstr=%errstr% ERROR UNINSTALLING SERVER.
)

:: Delete all the folders we created
rmdir /s /q %install_path%> nul 2>&1
rmdir /s /q %server_1_root%> nul 2>&1
rmdir /s /q %bruno_root_1%> nul 2>&1

:: If any uninstall errors then display them and exit
if not ("%errstr%")==("") goto error

:: Delete file used to mark the training installer as installed
del %installed_marker%> nul 2>&1

goto finished

:error
echo.
echo %errstr%
echo.
pause
exit /b 1

:finished
echo.
echo Training Install Finished. Start the server by calling:
echo .
echo start_training_server.bat
