#!/bin/bash

#------------------------------------------------------------------------------
# If exes are not already here, try to find them on the path.
for exe in p4 p4d p4broker; do
   if [[ ! -x ./$exe ]]; then
      if [[ -n "$(which $exe)" ]]; then
         echo Using $exe found on path.
         cp "$(which $exe)" .
      else
         if [[ $exe != p4broker ]]; then
            echo "Error: Missing executable file $exe"
         fi
      fi
   fi
done

if [[ -d "$PWD/trn_p4root" ]]; then
   echo "Cleaning up from earlier install."
   ./p4 -p 1666 -u bruno admin stop > /dev/null 2>&1
   sleep 1
   rm -rf $PWD/trn_p4root
fi

echo "Installing sample data with P4ROOT=$PWD/trn_p4root."
mkdir $PWD/trn_p4root
if [[ "$(uname)" == Darwin ]]; then
   ./p4d -r "$PWD/trn_p4root" -jr $PWD/checkpoint.mac
else
   ./p4d -r "$PWD/trn_p4root" -jr $PWD/checkpoint.linux
fi

./p4d -r "$PWD/trn_p4root" -xu
./p4d -r "$PWD/trn_p4root" "-cset server.depot.root=$PWD/depots"

if [[ "$(uname)" == Darwin ]]; then
   ./p4d -r "$PWD/trn_p4root" -p 1666 -J $PWD/trn_p4root/journal -L $PWD/trn_p4root/log -q -d
else
   ./p4d -C0 -r "$PWD/trn_p4root" -p 1666 -J $PWD/trn_p4root/journal -L $PWD/trn_p4root/log -q -d
fi

./p4 -p 1666 -u bruno -c bruno_ws client -o | sed "s#REPME#$HOME#" | ./p4 -p 1666 -u bruno client -i

if [[ -x ./p4broker ]]; then
   ./p4broker -C > p4broker.cfg
fi

if [[ -r p4v.tgz ]]; then
   tar -xvzf p4v.tgz
elif [[ -r P4V.dmg ]]; then
   open P4V.dmg
else
   echo "Install P4V from: https://www.perforce.com/downloads/helix-visual-client-p4v"
fi

echo Run "source p4vars" to set up your environment.
echo Run "./uninstall.sh" to remove the training environment.
